@@ -16,7 +16,7 @@ sub plugin_metaroles {
     }
 }
 
-around 'initialize_command' => sub {
+around 'initialize_command_class' => sub {
     my $orig = shift;
     my $self = shift;
     
@@ -61,4 +61,4 @@ This plugin generates a bash completion definition for your application.
 
 L<MooseX::App::Cmd::Command::BashComplete>
 
-=cut
\ No newline at end of file
+=cut
