@@ -16,7 +16,7 @@ sub plugin_metaroles {
     }
 }
 
-around 'initialize_command' => sub {
+around 'initialize_command_class' => sub {
     my $orig = shift;
     my $self = shift;
     
@@ -60,4 +60,4 @@ In your shell
 This plugin adds a command to display the version of your application,
 MooseX::App and perl.
 
-=cut
\ No newline at end of file
+=cut
