@@ -2,36 +2,30 @@ package Test03::SomeCommand;
 
 use MooseX::App::Command;
 extends qw(Test03);
+with qw(Test03::Role::TestRole);
  
-has 'some_option' => (
+option 'some_option' => (
     is            => 'rw',
     isa           => 'Str',
     documentation => q[Very important option!],
 );
 
-has 'another_option' => (
+option 'another_option' => (
     is            => 'rw',
     isa           => 'Str',
     required      => 1,
     cmd_flag      => 'another',
     cmd_tags      => ['Not important'],
 );
+
+has 'private' => (
+    is              => 'rw',
+    isa             => 'Str',
+);
  
 sub run {
     my ($self) = @_;
-    # Do something
+    print "RUN";
 }
 
-1;
-
-=encoding utf8
-
-=head1 NAME
-
-Test03::SomeCommand - Some command description
-
-=head1 DESCRIPTION
-
-Some long command description
-
-=cut
+1;
\ No newline at end of file
